(function() {
  'use strict';

  angular
    .module('bj12351')

    .directive('lsStar', function(templateUrlPath) {
      return {
        restrict: 'E',
        replace: true,
        templateUrl: templateUrlPath + 'modules/directives/star.html',
        require: '?ngModel',
        link: function(scope, element, attr, ngModel) {
          if (!ngModel) return;
          scope.clickStar = function(star) {
            scope.star = star;
            ngModel.$setViewValue(star);
          };
        }
      };
    })

    .directive('starRepeat', function() {
      return {
        restrict: 'A',
        transclude: true,
        replace: true,
        compile: function(element, attr) {
          var expression = attr.starRepeat;
          var match = expression.match(/^\s*([\s\S]+?)\s*$/);
          if (!match) {
            return console.error('starRepeat发生错误');
          }
          var len = match[1];
          return function(scope, element, attr) {
            scope.$watch(len, function(cv, ov) {
              //初始元素周围不能存在其他tagName相同的元素
              if (cv > 0) {
                element.css('display', '');
                element.parent().find(element[0].tagName).next().remove();
                for (var i = 0; i < cv - 1; i++) {
                  element.after(element.clone());
                }
              } else {
                element.css('display', 'none');
              }
            });
          };
        }
      };
    })

    .directive('hideTabBar', function() {
      var style = angular.element('<style>').html(
        '.has-tabs.no-tabs:not(.has-tabs-top) { bottom: 0;}\n' +
        '.no-tabs.has-tabs-top { top: 44px; }\n' +
        'div.tab-nav.tabs.slide-away.hide-tab-icon { bottom: -44px; }\n' +
        '.tab-nav.tabs.hide-tab-icon i {display:none}');
      document.body.appendChild(style[0]);
      return {
        restrict: 'A',
        compile: function(element, attr) {
          var tabBar = document.querySelector('.tab-nav');
          return function($scope, $element, $attr) {
            var scroll = $element[0].querySelector('.scroll-content');
            var footer = $element[0].querySelector('.bar-footer');
            $scope.$on('$ionicView.beforeEnter', function(e) {
              tabBar.classList.add('slide-away');
              tabBar.classList.add('hide-tab-icon');
              scroll.classList.add('no-tabs');
              if (footer) {
                footer.classList.add('no-tabs');
              }
            });
            $scope.$on('$ionicView.afterEnter', function(e) {
              scroll.classList.remove('has-tabs');
            });
          };
        }
      };
    })

    .directive('hideTabBarspecial', function() {
      var style = angular.element('<style>').html(
        '.has-tabs.no-tabs:not(.has-tabs-top) { bottom: 0;}\n' +
        '.no-tabs.has-tabs-top { top: 44px; }\n' +
        'div.tab-nav.tabs.slide-away.hide-tab-icon { bottom: -44px; }\n' +
        '.tab-nav.tabs.hide-tab-icon i {display:none}');
      document.body.appendChild(style[0]);
      return {
        restrict: 'A',
        compile: function(element, attr) {
          var tabBar = document.querySelector('.tab-nav');
          return function($scope, $element, $attr) {
            var scroll = $element[0].querySelector('.scroll-content');
            var footer = $element[0].querySelector('.bar-footer');
            $scope.$on('$ionicView.beforeEnter', function(e) {
              tabBar.classList.add('slide-away');
              tabBar.classList.add('hide-tab-icon');
              // scroll.classList.add('no-tabs');
              if (footer) {
                footer.classList.add('no-tabs');
              }
            });
          };
        }
      };
    })

    .directive('showTabBar', function() {
      return {
        restrict: 'A',
        compile: function(element, attr) {
          var tabBar = document.querySelector('.tab-nav');
          return function($scope, $element, $attr) {
            var scroll = $element[0].querySelector('.scroll-content');
            $scope.$on('$ionicView.beforeEnter', function(e) {
              tabBar.classList.remove('slide-away');
              tabBar.classList.remove('hide-tab-icon');
              scroll.classList.remove('no-tabs');
            });
          };
        }
      };
    })

    .directive('lsSubTab', function() {
      return {
        restrict: 'E',
        replace: true,
        scope: {
          index: '@'
        },
        transclude: true,
        template: '<a style="background-color:#e5e5e5;max-width:100%;" class="tab-item"><span class="tab-title" ng-transclude></span></a>',
        link: function(scope, element, attr) {
          var el = angular.element(element);

          if (scope.$parent.$parent.currentTab === parseInt(scope.index)) {
            el.addClass('tab-item-active');
            el.css('background-color', '#fff');
          }
          el.on('click', function() {
            el.parent().children().removeClass('tab-item-active');
            el.parent().children().css('background-color', '#e5e5e5');
            el.addClass('tab-item-active');
            el.css('background-color', '#fff');
            scope.$parent.$parent.currentTab = parseInt(scope.index);
            scope.$apply();
          });
        }
      };
    })

    .directive('lsSubTabs', function() {
      return {
        restrict: 'E',
        replace: false,
        transclude: true,
        scope: {
          currentTab: '='
        },
        template: '<div class="tabs-top tabs-striped"><div class="tab-nav tabs" style="line-height:2.4rem;height:4.8rem;" ng-transclude></div></div>',
        controller: function($scope, $element, $attrs, $transclude) {
          $scope.switchTab = function(tab) {
            $attrs.currentTab = tab;
          };
        }
      };
    })

    .directive('lsQrcode', function() {
      return {
        restrict: 'E',
        replace: true,
        scope: {
          content: '@',
          qrwidth: '@',
          qrheight: '@'
        },
        template: '<img></img>',
        link: function(scope, element, attr) {
          var width = parseInt(scope.qrwidth) || 80;
          var height = parseInt(scope.qrheight) || 80;
          var content = scope.content || '';
          var qrcode = new QRCode(element[0], {
            width: width,
            height: height
          });
          qrcode.makeCode(scope.content);
        }
      };
    })

    .directive('lsSrc', function(templateUrlPath) {
      return {
        restrict: 'A',
        link: function(scope, element, attr) {
          element[0].src = templateUrlPath + attr.lsSrc;
        }
      };
    })

    .directive('lsImg', function() {
      return {
        restrict: 'A',
        compile: function(element, attr) {
          angular.element(element).addClass('ls-animate-fadeout').addClass('ls-loading');
          return function(scope, element, attr) {
            element[0].onload = function(event) {
              angular.element(element).removeClass('ls-loading');
            };
            element[0].onerror = function(event) {
              element[0].src = 'img/default.png';
            };
          };
        }
      };
    })

    .directive('lsSubTabInMy', function() {
      return {
        restrict: 'E',
        replace: true,
        scope: {
          index: '@'
        },
        transclude: true,
        template: '<a style="background-color:#e5e5e5;max-width:100%;" class="tab-item"><span class="tab-title" ng-transclude></span></a>',
        link: function(scope, element, attr) {
          var el = angular.element(element);

          if (scope.$parent.$parent.currentTab === parseInt(scope.index)) {
            el.addClass('tab-item-active');
            el.css('background-color', '#fff');
          }
          el.on('click', function() {
            el.parent().children().removeClass('tab-item-active');
            el.parent().children().css('background-color', '#e5e5e5');
            el.addClass('tab-item-active');
            el.css('background-color', '#fff');
            scope.$parent.$parent.currentTab = parseInt(scope.index);
            scope.$apply();
          });
        }
      };
    })

    .directive('lsSubTabsInMy', function() {
      return {
        restrict: 'E',
        replace: false,
        transclude: true,
        scope: {
          currentTab: '='
        },
        template: '<div class="tabs-top tabs-striped"><div class="tab-nav tabs" style="top:0px;text-align:center;" ng-transclude></div></div>',
        controller: function($scope, $element, $attrs, $transclude) {
          $scope.switchTab = function(tab) {
            $attrs.currentTab = tab;
          };
        }
      };
    });


})();
