(function() {
  'use strict';
  angular
    .module('bj12351')
    /**匿名**/
    .filter('anonymous', function() {
      return function(name, is_anonymity) {
        if (is_anonymity) {
          name = '**' + name.substr(-1, 1);
        }
        return name;
      };
    })

    /**截取时间戳 月-日 时:分**/
    .filter('timeCut', function() {
      return function(timestamp) {
        timestamp = timestamp.replace(/-/g, '.');
        return timestamp.substring(5, (timestamp.length - 5));
      };
    })

    /**日期解析**/
    .filter('msgDateTrans', function() {
      return function(dateStr) {
        if (dateStr == "" || dateStr == undefined) {
          return "";
        }

        var now = new Date();
        var dateAry = dateStr.replace(/-|\s|:|\./g, ',').split(',');
        var year = dateAry[0];
        var month = dateAry[1] - 1 || 0;
        var day = dateAry[2] || 1;
        var hour = dateAry[3] || 0;
        var minute = dateAry[4] || 0;
        var second = dateAry[5] || 0;

        var beginTime = new Date(year, month, day, hour, minute, second);

        var beginYear = beginTime.getFullYear();
        var beginMouth = ("0" + (beginTime.getMonth() + 1)).slice(-2);
        var beginDate = ("0" + beginTime.getDate()).slice(-2);
        var beginHour = ("0" + beginTime.getHours()).slice(-2);
        var beginMinute = ("0" + beginTime.getMinutes()).slice(-2);
        var sign = now.getTime() - beginTime.getTime();

        if (-999 < sign && sign < 999) {
          return "刚刚";
        } else if (sign < 60000) {
          return parseInt(sign / 1000) + "秒前";
        } else if (sign < 3600000) {
          return parseInt(sign / 60000) + "分钟前";
        } else {
          if ((now.getFullYear() - beginYear) == 0) { //当前年
            if ((now.getMonth() - (beginMouth + 1)) == 0) { //当前月
              if (beginDate - now.getDate()) { //当前天
                return beginHour + ':' + beginMinute;
              }
              return beginMouth + '-' + beginDate; //不是当前天
            }
            return beginMouth + '-' + beginDate; //不是当前月
          }
          return beginYear + ''; //不是当前年
        }
      };
    })

    /**日期解析**/
    .filter('dateTrans', function() {
      function getDatestr(timestamp) {
        switch (timestamp.getDay()) {
          case 0:
            return "周日";
          case 1:
            return "周一";
          case 2:
            return "周二";
          case 3:
            return "周三";
          case 4:
            return "周四";
          case 5:
            return "周五";
          case 6:
            return "周六";
          default:
            return "";
        }
      }

      return function(dateStr) {
        if (dateStr == "" || dateStr == undefined) {
          return "";
        }

        var now = new Date();
        var dateAry = dateStr.replace(/-|\s|:|\./g, ',').split(',');
        var year = dateAry[0];
        var month = dateAry[1] - 1 || 0;
        var day = dateAry[2] || 1;
        var hour = dateAry[3] || 0;
        var minute = dateAry[4] || 0;
        var second = dateAry[5] || 0;

        var beginTime = new Date(year, month, day, hour, minute, second);

        var beginYear = beginTime.getFullYear();
        var beginMouth = ("0" + (beginTime.getMonth() + 1)).slice(-2);
        var beginDate = ("0" + beginTime.getDate()).slice(-2);
        var beginHour = ("0" + beginTime.getHours()).slice(-2);
        var beginMinute = ("0" + beginTime.getMinutes()).slice(-2);
        var sign = now.getTime() - beginTime.getTime();

        var common = beginYear + "-" + beginMouth + "-" + beginDate + " " + beginHour + ":" + beginMinute;
        var commonNow = beginMouth + "-" + beginDate + " " + beginHour + ":" + beginMinute;
        if (-999 < sign && sign < 999) {
          return "刚刚";
        } else if (sign < 0) {
          switch (beginYear - now.getFullYear()) {
            case 0:
              switch (beginMouth - 1 - now.getMonth()) {
                case 0:
                  switch (beginDate - now.getDate()) {
                    case 0:
                      return beginHour + ":" + beginMinute;
                    case 1:
                      return '明天 ' + beginHour + ":" + beginMinute;
                    default:
                      return getDatestr(beginTime) + ' ' + beginHour + ":" + beginMinute;
                  }
                  break;
                default:
                  return common;
              }
              break;
            default:
              return common;
          }
        } else if (sign < 60000) {
          return parseInt(sign / 1000) + "秒前";
        } else if (sign < 3600000) {
          return parseInt(sign / 60000) + "分钟前";
        } else {
          switch (now.getFullYear() - beginYear) {
            case 0:
              switch ((now.getMonth() - beginMouth) + 1) {
                case 0:
                  var offset = now.getDate() - beginDate;
                  switch (offset) {
                    case 0:
                      return beginHour + ":" + beginMinute;
                    case 1:
                      if (beginTime.getDay() == 0) {
                        return commonNow;
                      }
                      return '昨天 ' + beginHour + ":" + beginMinute;
                    default:
                      if (offset < 7) {
                        if (beginTime.getDay() > now.getDay()) {
                          return commonNow;
                        }
                        return getDatestr(beginTime) + ' ' + beginHour + ":" + beginMinute;
                      }
                      return commonNow;
                  }
                  break;

                default:
                  return commonNow;
              }
              break;

            default:
              return common;
          }
        }
      };
    })

    /**信息安全**/
    .filter('protectInfo', function() {
      return function(number) {
        if (number != undefined) {
          switch (number.length) {
            case 11:
              return '*****' + number.slice(7);
            case 16:
              return '*****' + number.slice(12);
            default:
              return number.slice(0, 6) + '********' + number.slice(14);
          }
        }
      };
    })

    /**获取代码值对应名**/
    .filter('codelist', function($http) {
      return function(code, list_name) {
        var list = JSON.parse(localStorage.getItem('bj12351.' + list_name));
        for (var i = 0; i < list.length; i++) {
          if (code == list[i].code) {
            return list[i].name;
          }
        }
      };
    })

    /**处理状态**/
    .filter('isProcess', function() {
      return function(number) {
        switch (number) {
          case 0:
            return '处理中';
          case 1:
            return '处理成功';
          case 2:
            return '处理失败';
        }
      };
    })

    /**审核状态**/
    .filter('verifyStatus', function() {
      return function(number) {
        switch (number) {
          case 0:
            return '未审核';
          case 1:
            return '审核通过';
          case 2:
            return '审核未通过';
        }
      };
    })

    /**金额划分**/
    .filter('moneyDivide', function() {
      return function(money) {
        if (!money) {
          return "";
        }
        var dotIndex = money.indexOf('.');
        var regex = /(\d{1,3})(?=(\d{3})+$)/g;
        if (dotIndex == -1) {
          return money.replace(regex, '$1,') + ".00";
        } else {
          var pre = money.substr(0, dotIndex);
          var suf = money.substr(dotIndex, money.length);
          pre = pre.replace(regex, '$1,');
          return pre + suf;
        }
      };
    });

})();
