(function() {
  'use strict';
  angular
    .module('bj12351')

    .factory('tools', function() {
      return {
        //校验日期
        verDate: function(date) {
          var regex = /^(\d{4})-(\d{2})-(\d{2})$/;
          if (regex.test(date)) {
            return 0;
          }
          return -1;
        },

        //校验手机号
        verMobile: function(mobile) {
          var regex = /^1\d{10}$/;
          if (regex.test(mobile)) {
            return 0;
          }
          return -1;
        },

        //校验身份证号
        verCertNum: function(certNum) {
          if (certNum.length != 18) {
            return -1;
          }
          certNum = certNum.toUpperCase();
          var area = [11, 12, 13, 14, 15, 21, 22, 23, 31, 32, 33, 34, 35, 36, 37, 41, 42, 43, 44, 45, 46, 50, 51, 52, 53, 54, 61, 62, 63, 64, 65, 71, 81, 82, 91];
          var weight = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
          var checkCode = [1, 0, 'X', 9, 8, 7, 6, 5, 4, 3, 2];
          var idCardArray = certNum.split("");
          var sum = 0;

          // 地区检验
          if (area.indexOf(parseInt(certNum.substr(0, 2))) < 0) { //身份证号地区码非法
            return -2;
          }

          //身份号码校验位
          for (var i = 0; i < 17; i++) {
            sum += parseInt(certNum[i]) * weight[i];
          }
          if (certNum[17] == checkCode[sum % 11]) { //判断校验码位
            return 0;
          } else { //校验位验证不通过
            return -3;
          }
        },

        //生成验证吗
        createVerCode: function() {
          var codeLength = 4; //验证码长度
          var selectChar = new Array( //所有候选组成验证码的字符，当然也可以用中文的
            0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
            'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
            'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z'
          );
          var codeRandom = "";
          for (var i = 0; i < codeLength; i++) {
            var codeIndex = Math.floor(Math.random() * 62);
            codeRandom += selectChar[codeIndex]; //生成4位验证码
          }
          return codeRandom;
        },

        //校验验证码
        verifyVerCode: function(showCode, inputCode) {
          if (!showCode || !inputCode) {
            return false;
          }
          return showCode.toUpperCase() == inputCode.toUpperCase();
        }
      };
    })

    .factory('md5Ser', function() {
      return {
        md5: function(str) {
          return hex_md5(str);
        }
      };
    })

    .factory('analysisSer', function($http, API, mySer) {
      return {
        login: function() {
          if (localStorage.getItem('bj12351.token')) {
            $http.post(API.getHost() + '/user/analysis/login.jsp', {
                token: localStorage.getItem('bj12351.token')
              })
              .success(function(data) {
                if (data.errcode === -1) {
                  localStorage.removeItem('bj12351.token', undefined);
                  localStorage.removeItem('bj12351.user', undefined);
                } else if (data.errcode === 0) {
                  mySer.info(localStorage.getItem('bj12351.token'));
                }
              });
          }
        }
      };
    })

    .factory('geoLocationSer', function($ionicPlatform, $cordovaGeolocation, $ionicLoading) {
      var latitude = localStorage.getItem('bj12351.latitude') || '';
      var longitude = localStorage.getItem('bj12351.longitude') || '';
      var convertor = new Convertor();

      function located() {
        $cordovaGeolocation.getCurrentPosition({
          maximumAge: 3000,
          timeout: 3000,
          enableHighAccuracy: false
        }).then(function(position) {
          var BD09 = convertor.WGS2BD09({
            lng: parseFloat(position.coords.longitude),
            lat: parseFloat(position.coords.latitude)
          });
          console.log(BD09);

          latitude = BD09.lat;
          longitude = BD09.lng;
          localStorage.setItem('bj12351.latitude', latitude);
          localStorage.setItem('bj12351.longitude', longitude);
        }, function(error) {
          if (localStorage.getItem('bj12351.latitude')) {
            localStorage.removeItem('bj12351.latitude');
          }
          if (localStorage.getItem('bj12351.longitude')) {
            localStorage.removeItem('bj12351.longitude');
          }
          console.log(error);
          // $ionicLoading.show({
          //   template: '获取定位超时，请确认手机已开启定位',
          //   duration: 1000
          // });
        });
      }

      $ionicPlatform.ready(function() {
        located();
      });

      return {
        reLocated: function() {
          located();
        },
        getLatitude: function() {
          return latitude;
        },

        getLongitude: function() {
          return longitude;
        }
      };
    })

    .factory('codelistSer', function($http, $q, API, $ionicLoading) {
      var codelists = {};
      var codeunionlists = {};
      return {
        getList: function() {
          return codelists;
        },
        getUnionList: function() {
          return codeunionlists;
        },
        codelist: function(list_name) {
          var q = $q.defer();
          $http.get(API.getHost() + '/system/codelist.jsp?list_name=' + list_name)
            .success(function(data) {
              codelists[list_name] = data;
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            });
          return q.promise;
        },
        codeUnionList: function(list_name) {
          var q = $q.defer();
          $http.get(API.getHost() + '/system/code-list-union.jsp?list_name=' + list_name)
            .success(function(data) {
              codeunionlists[list_name] = data;
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            });
          return q.promise;
        }
      };
    })

    .factory('scanBarcodeSer', function($rootScope, $ionicPlatform, $q, $http, API, $ionicLoading, $ionicPopup, $cordovaDialogs, $cordovaBarcodeScanner, $state, $location, $cordovaInAppBrowser) {
      //判断用户是否有扫一扫资格
      function live_scan_verify(service_id, firm_id) {
        $ionicLoading.show({
          template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
        });
        var q = $q.defer();
        $http.get(API.getHdHost() + '/check/live_scan_verify.jsp?service_id=' + service_id + '&firm_id=' + firm_id + '&token=' + localStorage.getItem('bj12351.token'), {
            timeout: 30000
          })
          .success(function(data) {
            q.resolve(data);
          })
          .error(function(error) {
            q.reject(error);
          })
          .finally(function() {
            $ionicLoading.hide();
          });
        return q.promise;
      }

      //服务验证
      function check(token, service_id, firm_id) {
        firm_id = firm_id || 0;
        var q = $q.defer();
        $ionicLoading.show({
          template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
        });
        $http.post(API.getHdHost() + '/check/take-service.jsp', {
            service_id: service_id,
            token: token,
            firm_id: firm_id
          }, {
            timeout: 10000
          })
          .success(function(data) {
            q.resolve(data);
          })
          .error(function(error) {
            q.reject(error);
          })
          .finally(function() {
            $ionicLoading.hide();
          });
        return q.promise;
      }

      //现场领取
      // function take(token, service_id, firm_id) {
      //   firm_id = firm_id || 0;
      //   var q = $q.defer();
      //   $ionicLoading.show({
      //     template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
      //   });
      //   $http.post(API.getHdHost() + '/check/get-service.jsp', {
      //       service_id: service_id,
      //       token: token,
      //       firm_id: firm_id
      //     }, {
      //       timeout: 10000
      //     })
      //     .success(function(data) {
      //       q.resolve(data);
      //     })
      //     .error(function(error) {
      //       q.reject(error);
      //     })
      //     .finally(function() {
      //       $ionicLoading.hide();
      //     });
      //   return q.promise;
      // }

      //现场预定
      function scanReserve(token, service_id) {
        var q = $q.defer();
        $ionicLoading.show({
          template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
        });
        $http.post(API.getHdHost() + '/check/reserve-service.jsp', {
            service_id: service_id,
            token: token
          }, {
            timeout: 10000
          })
          .success(function(data) {
            q.resolve(data);
          })
          .error(function(error) {
            q.reject(error);
          })
          .finally(function() {
            $ionicLoading.hide();
          });
        return q.promise;
      }

      //会籍转入
      function manageOrg(target_org, target_enter) {
        var q = $q.defer();
        $ionicLoading.show({
          template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
        });
        $http.post(API.getHost() + '/user/manage-org.jsp', {
            token: localStorage.getItem('bj12351.token'),
            target_org: target_org,
            target_enter: target_enter,
            type: 1,
            hy_member_id: JSON.parse(localStorage.getItem('bj12351.user')).hy_id,
            source: 2
          }, {
            timeout: 10000
          })
          .success(function(data) {
            q.resolve(data);
          })
          .error(function(error) {
            q.reject(error);
          })
          .finally(function() {
            $ionicLoading.hide();
          });
        return q.promise;
      }


      //职工之家扫码获取职工之家部分详情信息
      function scanVerifyEmployee(employee_id) {
        var q = $q.defer();
        $ionicLoading.show({
          template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
        });
        $http.post(API.getHost() + '/employee/scan-verify.jsp', {
            employee_id: employee_id,
            token: localStorage.getItem('bj12351.token')
          }, {
            timeout: 10000
          })
          .success(function(data) {
            q.resolve(data);
          })
          .error(function(error) {
            q.reject(error);
          })
          .finally(function() {
            $ionicLoading.hide();
          });
        return q.promise;
      }

      //JSON校验
      function isJSON(str) {
        if (typeof(str) == 'string') {
          try {
            var obj = JSON.parse(str);
            if (typeof(obj) == 'object' && obj) {
              return true;
            } else {
              return false;
            }
          } catch (e) {
            console.log('error：' + str + '!!!' + e);
            return false;
          }
        }
      }


      //验证
      function doCheck(data) {
        data = data.trim();
        if (!isJSON(data)) {
          if (data.substring(0, 4) === 'http') {
            $ionicPopup.confirm({
              title: '非本应用二维码，可能存在风险，是否打开此链接？',
              template: data,
              buttons: [{
                text: '取消'
              }, {
                text: '打开链接',
                type: 'button-positive',
                onTap: function(e) {
                  $cordovaInAppBrowser.open(data, '_blank');
                }
              }]
            });
          } else {
            localStorage.setItem('bj12351.scan_result', data);
            $state.go('tab.scanResult');
          }
        } else {
          data = JSON.parse(data);
          if (data.code_type !== 'check_service' && data.code_type !== 'get_service' && data.code_type !== 'reserve_service' && data.code_type !== 'enterprise' && data.code_type !== 'employeehome') {
            localStorage.setItem('bj12351.scan_result', JSON.stringify(data));
            $state.go('tab.scanResult');
            return;
          }
          if (localStorage.getItem('bj12351.token')) {
            if (data.code_type == 'check_service') {
              check(localStorage.getItem('bj12351.token'), data.service_id, data.firm_id).then(function(data) {
                if (data.errcode === 0) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '参加活动成功，去评价一下吧~',
                    buttons: [{
                      text: '稍后评价'
                    }, {
                      text: '现在评价',
                      type: 'button-positive',
                      onTap: function(e) {
                        $location.path('/tab/my-service');
                      }
                    }]
                  });
                } else if (data.errcode == -1) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '您尚未登录哦',
                    buttons: [{
                      text: '稍后登录'
                    }, {
                      text: '现在登录',
                      type: 'button-positive',
                      onTap: function(e) {
                        if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                          $state.go('tab.login');
                        } else {
                          $state.go('tab.login-other');
                        }
                      }
                    }]
                  });
                } else if (data.errcode == -2) {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: data.errmsg,
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                }
              }, function(error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
            } else if (data.code_type == 'get_service') { //现场发放
              //  localStorage.setItem('bj12351.scan_reserve', data);
              live_scan_verify(data.service_id, data.firm_id).then(function(data) {
                if (data.errcode === 0) {
                  var listDataAll = angular.toJson(data);
                  $state.go('tab.scanReserve', {
                    data_scan: listDataAll
                  });
                } else if (data.errcode == -1) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '您尚未登录哦',
                    buttons: [{
                      text: '稍后登录'
                    }, {
                      text: '现在登录',
                      type: 'button-positive',
                      onTap: function(e) {
                        if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                          $state.go('tab.login');
                        } else {
                          $state.go('tab.login-other');
                        }
                      }
                    }]
                  });
                } else if (data.errcode == -2) {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: data.errmsg,
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                }
              }, function(error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });



              // take(localStorage.getItem('bj12351.token'), data.service_id, data.firm_id).then(function (data) {
              //   if (data.errcode === 0) {
              //     $ionicPopup.confirm({
              //       title: '温馨提示',
              //       template: '恭喜！您是第' + data.number + '位参加此活动的会员，去评价一下吧~',
              //       buttons: [{
              //         text: '稍后评价'
              //       }, {
              //         text: '现在评价',
              //         type: 'button-positive',
              //         onTap: function (e) {
              //           $location.path('/tab/my-service');
              //         }
              //       }]
              //     });
              //   } else if (data.errcode == -1) {
              //     $ionicPopup.confirm({
              //       title: '温馨提示',
              //       template: '您尚未登录哦。',
              //       buttons: [{
              //         text: '稍后登录'
              //       }, {
              //         text: '现在登录',
              //         type: 'button-positive',
              //         onTap: function (e) {
              //           if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
              //             $state.go('tab.login');
              //           } else {
              //             $state.go('tab.login-other');
              //           }
              //         }
              //       }]
              //     });
              //   } else if (data.errcode == -2) {
              //     $ionicPopup.alert({
              //       title: '温馨提示',
              //       template: data.errmsg,
              //       buttons: [{
              //         text: '好的',
              //         type: 'button-positive'
              //       }]
              //     });
              //   }
              // }, function (error) {
              //   $ionicLoading.show({
              //     template: '网络繁忙，请稍后重试。',
              //     duration: 1000
              //   });
              // });
            } else if (data.code_type == 'reserve_service') {
              scanReserve(localStorage.getItem('bj12351.token'), data.service_id).then(function(data) {
                if (data.errcode === 0) {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: '恭喜！您是第' + data.number + '位参加此活动的会员。',
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                } else if (data.errcode == -1) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '您尚未登录哦。',
                    buttons: [{
                      text: '稍后登录'
                    }, {
                      text: '现在登录',
                      type: 'button-positive',
                      onTap: function(e) {
                        if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                          $state.go('tab.login');
                        } else {
                          $state.go('tab.login-other');
                        }
                      }
                    }]
                  });
                } else if (data.errcode == -2) {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: data.errmsg,
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                }
              }, function(error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
            } else if (data.code_type == 'enterprise') {
              manageOrg(data.org_id, data.enterprise_id).then(function(data) {
                if (data.errcode === 0) {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: '会籍变更申请提交成功。',
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                } else if (data.errcode == -1) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '您尚未登录哦。',
                    buttons: [{
                      text: '稍后登录'
                    }, {
                      text: '现在登录',
                      type: 'button-positive',
                      onTap: function(e) {
                        if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                          $state.go('tab.login');
                        } else {
                          $state.go('tab.login-other');
                        }
                      }
                    }]
                  });
                } else {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: data.errmsg,
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                }
              }, function(error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
            } else if (data.code_type == 'employeehome') {
              scanVerifyEmployee(data.employee_home_id).then(function(data) {
                // if (data.errcode === 0) {
                //   $ionicPopup.alert({
                //     title: '温馨提示',
                //     template: '参与成功。',
                //     buttons: [{
                //       text: '好的',
                //       type: 'button-positive'
                //     }]
                //   });
                // }
                if (data.errcode == undefined) {
                  var listDataHome = angular.toJson(data);
                  $state.go('tab.scanEmployee', {
                    data_scan: listDataHome
                  });
                } else if (data.errcode == -1) {
                  $ionicPopup.confirm({
                    title: '温馨提示',
                    template: '您尚未登录哦。',
                    buttons: [{
                      text: '稍后登录'
                    }, {
                      text: '现在登录',
                      type: 'button-positive',
                      onTap: function(e) {
                        if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                          $state.go('tab.login');
                        } else {
                          $state.go('tab.login-other');
                        }
                      }
                    }]
                  });
                } else {
                  $ionicPopup.alert({
                    title: '温馨提示',
                    template: data.errmsg,
                    buttons: [{
                      text: '好的',
                      type: 'button-positive'
                    }]
                  });
                }
              }, function(error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
            }
          } else {
            $ionicPopup.confirm({
              title: '温馨提示',
              template: '您尚未登录哦。',
              buttons: [{
                text: '稍后登录'
              }, {
                text: '现在登录',
                type: 'button-positive',
                onTap: function(e) {
                  // $location.path('/tab/login');
                  if (localStorage.getItem('bj12351.is_gesture_pwd') === "true") {
                    $state.go('tab.login');
                  } else {
                    $state.go('tab.login-other');
                  }
                }
              }]
            });
          }
        }
      }

      return {
        scan: function() {
          if ($rootScope.is_scan) {
            return;
          }
          $rootScope.is_scan = true;
          $cordovaBarcodeScanner.scan().then(function(imageData) {
              if (!imageData.cancelled) {
                switch (imageData.format) {
                  case 'QR_CODE':
                    localStorage.setItem('bj12351.scan_result_type', '二维码');
                    doCheck(imageData.text);
                    break;
                  case 'EAN_13':
                    localStorage.setItem('bj12351.scan_result', imageData.text);
                    localStorage.setItem('bj12351.scan_result_type', '条形码');
                    $state.go('tab.scanResult');
                    break;
                }
              }
            }, function(error) {
              if (error == 'Illegal access') {
                $cordovaDialogs.alert('访问摄像头的权限已被禁用，请前往设置开启', '温馨提示', '好的');
              } else {
                $cordovaDialogs.alert(error, '温馨提示', '好的');
              }
            })
            .finally(function() {
              $rootScope.is_scan = false;
            });
        },
        //现场领取
        take: function(token, service_id, firm_id, reserve_count, phone) {
          firm_id = firm_id || 0;
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.post(API.getHdHost() + '/check/get-service-3.jsp', {
              service_id: service_id,
              token: token,
              firm_id: firm_id,
              reserve_count: reserve_count,
              phone: phone
            }, {
              timeout: 10000
            })
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });
          return q.promise;
        },

        //职工之家扫码预定或赴约
        scanEmployee: function(employee_id, book_content) {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.post(API.getHost() + '/employee/scan.jsp', {
              type: 2, //扫一扫
              employee_id: employee_id || 0,
              book_content: book_content,
              token: localStorage.getItem('bj12351.token'),
              hy_id: JSON.parse(localStorage.getItem('bj12351.user')).hy_id || 0
            }, {
              timeout: 10000
            })
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });
          return q.promise;
        }


      };
    })

    .factory('versionSer', function($cordovaDialogs, $cordovaDevice, $http, API, $q) {
      var localVersion = localStorage.getItem('bj12351.app_version');

      return {
        checkUpdate: function() {
          var q = $q.defer();
          $http.get(API.getHost() + '/system/check-android-version.jsp?platform=' + $cordovaDevice.getPlatform(), {
              timeout: 10000
            }).success(function(data) {
              if (data.version) {
                q.resolve(data.version !== localVersion);
              } else {
                q.resolve(false);
              }
            })
            .error(function(err) {
              q.resolve(false);
            });
          return q.promise;
        }
      };
    })
    .factory('adsService', function($http, API, $q, $ionicLoading) {
      var ads = JSON.parse(localStorage.getItem("bj12351.ads")) || [];
      return {
        getAds: function() {
          return ads;
        },
        refreshAds: function() {
          var q = $q.defer();
          $http.get(API.getPortalBjzghHost() + '/ads/ads.jsp', {
              timeout: 10000
            })
            .success(function(data) {
              if (data.errcode === undefined) {
                ads = data;
                localStorage.setItem('bj12351.ads', JSON.stringify(data));
              }
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            });
          return q.promise;
        }
      };
    });

})();
