(function() {
  'use strict';

  angular
    .module('joinUnion')
    .controller('joinUnionCtrl', function($scope, $cordovaDialogs, $ionicLoading, $ionicHistory, $ionicModal, templateUrlPath, mySer, joinUnionSer) {
      $scope.user = {};
      $scope.user.name = '';
      $scope.user.id_card = '';
      $scope.user.phone = '';
      $scope.user.company = '';
      $scope.user.company_address = '';

      /*------工作单位部分开始------*/
      $scope.company_list = [];
      $scope.company_page = 1;
      $scope.company_size = 20;
      $scope.user.company_name = '';
      $scope.doCompanyRefresh = function() {
        if ($scope.user.company === undefined || $scope.user.company === "") {
          $cordovaDialogs.alert('请填写单位名称', '温馨提示', '好的');
          return;
        }
        joinUnionSer.companyList($scope.user.company).then(function(data) {
            if (data.errcode === undefined) {
              $scope.company_list = data;
            } else {
              $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的').then(function() {
                $scope.company_list = [];
              });
            }
          }, function(error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          })
          .finally(function() {
            $scope.$broadcast('scroll.refreshComplete');
          });
      };

      $scope.modal = {};
      $scope.openModal = function(modal_name) {
        $ionicModal.fromTemplateUrl(templateUrlPath + 'modules/modals/' + modal_name + '.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function(modal) {
          if (modal_name === 'select_company') {
            $scope.user.company = '';
            $scope.company_list = [];
          }
          $scope.modal[modal_name] = modal;
          $scope.modal[modal_name].show();
        });
      };

      $scope.closeModal = function(modal_name) {
        $scope.modal[modal_name].remove();
      };

      $scope.removeModal = function(modal_name) {
        $scope.modal[modal_name].remove();
      };

      $scope.submitModal = function(modal_name) {
        if (modal_name === 'select_company') {
          if ($scope.company_list === undefined || $scope.company_list.length === 0) {
            $scope.user.company_name = $scope.user.company;
          }

        }
        $scope.modal[modal_name].remove();
      };
      /*------工作单位部分结束------*/

      /**校验身份证号**/
      function verifyIdCard(code) {
        var city = {
          11: "北京",
          12: "天津",
          13: "河北",
          14: "山西",
          15: "内蒙古",
          21: "辽宁",
          22: "吉林",
          23: "黑龙江",
          31: "上海",
          32: "江苏",
          33: "浙江",
          34: "安徽",
          35: "福建",
          36: "江西",
          37: "山东",
          41: "河南",
          42: "湖北 ",
          43: "湖南",
          44: "广东",
          45: "广西",
          46: "海南",
          50: "重庆",
          51: "四川",
          52: "贵州",
          53: "云南",
          54: "西藏 ",
          61: "陕西",
          62: "甘肃",
          63: "青海",
          64: "宁夏",
          65: "新疆",
          71: "台湾",
          81: "香港",
          82: "澳门",
          91: "国外 "
        };
        var tip = "";
        var pass = true;

        if (!code || !/^[1-9]\d{5}((1[89]|20)\d{2})(0[1-9]|1[0-2])(0[1-9]|[12]\d|3[01])\d{3}[\dxX]$/i.test(code)) {
          tip = "身份证号格式错误";
          pass = false;
        } else if (!city[code.substr(0, 2)]) {
          tip = "地址编码错误";
          pass = false;
        } else {
          //18位身份证需要验证最后一位校验位
          if (code.length == 18) {
            code = code.split('');
            //∑(ai×Wi)(mod 11)
            //加权因子
            var factor = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
            //校验位
            var parity = [1, 0, 'X', 9, 8, 7, 6, 5, 4, 3, 2];
            var sum = 0;
            var ai = 0;
            var wi = 0;
            for (var i = 0; i < 17; i++) {
              ai = code[i];
              wi = factor[i];
              sum += ai * wi;
            }
            var last = parity[sum % 11];
            if (parity[sum % 11] != code[17].toUpperCase()) {
              tip = "校验位错误";
              pass = false;
            }
          }
        }
        return pass;
      }

      /**根据身份证号获取年龄**/
      function GetAge(identityCard) {
        var len = (identityCard + "").length;
        if (len == 0) {
          return 0;
        } else {
          if ((len != 15) && (len != 18)) //身份证号码只能为15位或18位其它不合法
          {
            return 0;
          }
        }
        var strBirthday = "";
        if (len == 18) //处理18位的身份证号码从号码中得到生日和性别代码
        {
          strBirthday = identityCard.substr(6, 4) + "/" + identityCard.substr(10, 2) + "/" + identityCard.substr(12, 2);
        }
        if (len == 15) {
          strBirthday = "19" + identityCard.substr(6, 2) + "/" + identityCard.substr(8, 2) + "/" + identityCard.substr(10, 2);
        }
        //时间字符串里，必须是“/”
        var birthDate = new Date(strBirthday);
        var nowDateTime = new Date();
        var age = nowDateTime.getFullYear() - birthDate.getFullYear();
        //再考虑月、天的因素;.getMonth()获取的是从0开始的，这里进行比较，不需要加1
        if (nowDateTime.getMonth() < birthDate.getMonth() || (nowDateTime.getMonth() == birthDate.getMonth() && nowDateTime.getDate() < birthDate.getDate())) {
          age--;
        }
        return age;
      }

      /**根据条件获取对象**/
      var getObjByCondition = function(code3, list_name) {
        var result = [];
        var i = 0;
        var j = 0;
        var list = JSON.parse(localStorage.getItem('bj12351.' + list_name)) || {};
        if (code3 === 0) {
          for (i; i < list.length; i++) {
            if (0 === list[i].code4) {
              result[j] = list[i];
              j++;
            }
          }
          return result;
        } else {
          for (i; i < list.length; i++) {
            if (code3 == list[i].code3) {
              result[j] = list[i];
              j++;
            }
          }
          result.shift();
          return result;
        }
      };

      $scope.first_areas = getObjByCondition(0, 'ct_area') || {}; //二级联动中一级列表
      $scope.second_areas = $scope.first_areas; //二级联动中二级列表
      $scope.user.my_city_area = $scope.first_areas[0] || {}; //一级列表初值
      $scope.user.my_country_area = $scope.user.my_city_area; //二级列表初值
      $scope.my_city_area_flag = true;
      $scope.is_submit = false; //是否可提交

      /**选择一级列表**/
      $scope.chooseFirst = function() {
        $scope.second_areas = getObjByCondition($scope.user.my_city_area.code3, 'ct_area'); //二级列表赋值
        if ($scope.user.my_city_area !== $scope.first_areas[0]) { //当一级列表不为请选择时
          $scope.user.my_country_area = $scope.second_areas[0] || {};
          $scope.my_city_area_flag = false;
        } else { //当一级列表为请选择时
          $scope.user.my_country_area = $scope.second_areas[0] || {};
          $scope.my_city_area_flag = true;
        }
      };

      /**提交**/
      $scope.submit = function() {
        if ($scope.is_submit === true) {
          $cordovaDialogs.alert('正在提交中，请耐心等待。', '温馨提示', '好的');
          return;
        }
        $scope.is_submit = true;

        if ($scope.user.name === "") {
          $cordovaDialogs.alert('姓名不能为空！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if (!verifyIdCard($scope.user.id_card)) {
          $cordovaDialogs.alert('请正确填写身份证号！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if (parseInt($scope.user.id_card.substr(16, 1)) % 2 == 1) { //是男则执行代码 ...
          if (GetAge($scope.user.id_card) > 60) {
            $cordovaDialogs.alert('年龄超过退休年龄不能进行入会申请！', '温馨提示', '好的');
            $scope.is_submit = false;
            return;
          }
        } else { //是女则执行代码 ...
          if (GetAge($scope.user.id_card) > 55) {
            $cordovaDialogs.alert('年龄超过退休年龄不能进行入会申请！', '温馨提示', '好的');
            $scope.is_submit = false;
            return;
          }
        }

        if ($scope.user.phone.toString().length === 0) {
          $cordovaDialogs.alert('手机号不能为空！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if ($scope.user.phone.toString().length != 11) {
          $cordovaDialogs.alert('请正确填写手机号！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if ($scope.user.company_name === "") {
          $cordovaDialogs.alert('工作单位不能为空！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if ($scope.user.company_address === "") {
          $cordovaDialogs.alert('单位地址不能为空！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if ($scope.user.my_city_area.name == "请选择") {
          $scope.company_address_full = "" + "" + $scope.user.company_address;
        } else {
          $scope.company_address_full = $scope.user.my_city_area.name + $scope.user.my_country_area.name + $scope.user.company_address;
        }
        if ($scope.company_address_full !== "" && $scope.company_address_full.length > 128) {
          $cordovaDialogs.alert('单位地址不能超过128个字！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        mySer.isCollected($scope.user.id_card.toUpperCase()).then(function(data) {
          if (data.isCollected === true) {
            $cordovaDialogs.alert('您已是会员,无需提交入会资料。请注册、登录，查看本人信息。', '温馨提示', '好的');
            $scope.is_submit = false;
          } else {
            joinUnionSer.applyJoin($scope.user.name, $scope.user.id_card.toUpperCase(), $scope.user.phone, $scope.user.company_name, $scope.company_address_full).then(function(data) {
              if (data.errcode === 0) {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
                $scope.user.name = '';
                $scope.user.id_card = '';
                $scope.user.phone = '';
                $scope.user.company = '';
                $scope.user.company_address = '';
                $scope.user.my_city_area = $scope.first_areas[0] || {}; //一级列表初值
                $scope.chooseFirst();

                $ionicHistory.goBack();
              } else if (data.errcode == -2) {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
                $scope.is_submit = false;
              } else {
                $cordovaDialogs.alert('提交失败，请稍后重试。', '温馨提示', '好的');
                $scope.is_submit = false;
              }
            }, function() {
              $scope.is_submit = false;
              $ionicLoading.show({
                template: '网络繁忙，请稍后重试。',
                duration: 1000
              });
            });
          }
        }, function() {
          $scope.is_submit = false;
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        });
      };

    });
})();
