(function() {
  'use strict';

  angular
    .module('login')
    .factory('loginSer', function($http, API, $q, $ionicLoading) {
      var user = JSON.parse(localStorage.getItem('bj12351.user')) || {};

      return {
        getUserInfo: function() {
          return user;
        },

        login: function(login_name, password, login_type) {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.post(API.getHost() + '/user/login.jsp', {
              login_name: login_name,
              password: password,
              login_type: login_type,
              jpush_id: localStorage.getItem('bj12351.jpush_id')
            }, {
              timeout: 10000
            })
            .success(function(data) {
              if (data.errcode == 0) {
                localStorage.setItem('bj12351.token', data.token);
              }
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });
          return q.promise;
        },

        //获取用户信息
        info: function() {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.get(API.getHost() + '/user/info.jsp?token=' + localStorage.getItem('bj12351.token'), {
              timeout: 10000
            })
            .success(function(data) {
              if (data.errcode === undefined) {
                user = data;
                localStorage.setItem('bj12351.user', JSON.stringify(data));
                localStorage.setItem('bj12351.id_card', data.id_card);
              }
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });
          return q.promise;
        },

        //获取验证按
        getValidCode: function(card) {
          var q = $q.defer();
          $http.post(API.getHost() + '/user/forget-valid-code.jsp', {
              card: card
            }, {
              timeout: 10000
            })
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            });
          return q.promise;
        },

        //忘记密码
        forgetPwd: function(valid_code, card, password) {
          var q = $q.defer();
          $http.post(API.getHost() + '/user/modify-password-by-valid-code.jsp', {
              valid_code: valid_code,
              card: card,
              password: password
            }, {
              timeout: 10000
            })
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            });
          return q.promise;
        },
        /*设置手势密码*/
        setGesturePassword: function(token, password) {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.get(API.getHost() + '/user/set_gesture_pw.jsp?token=' + token + '&password=' + password)
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });

          return q.promise;
        },
        /*设置是否使用手势密码*/
        setIsGesturePwd: function(token, is_gesture_pwd) {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.get(API.getHost() + '/user/is_gesture_pwd.jsp?token=' + token + '&is_gesture_pwd=' + is_gesture_pwd)
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });

          return q.promise;
        },
        //手势密码登录
        gestureLogin: function(login_name, password) {
          var q = $q.defer();
          $ionicLoading.show({
            template: '<ion-spinner icon="android" class="spinner-light"></ion-spinner>'
          });
          $http.post(API.getHost() + '/user/gesture_login.jsp', {
              login_name: login_name,
              password: password,
              jpush_id: localStorage.getItem('bj12351.jpush_id')
            })
            .success(function(data) {
              q.resolve(data);
            })
            .error(function(error) {
              q.reject(error);
            })
            .finally(function() {
              $ionicLoading.hide();
            });
          return q.promise;
        }

      };
    });
})();
