(function () {
  'use strict';
  angular
    .module('merchant')
    .controller('merchantCtrl', function ($scope, $ionicModal, $ionicLoading, $cordovaDialogs, $state, templateUrlPath, merchantSer, geoLocationSer) {
      $scope.search = {};
      $scope.search.name = '';

      $scope.merchants = merchantSer.getMerchants();
      $scope.hasMore = $scope.merchants.length >= size;

      var page = 1;
      var size = 10;

      var latitude = geoLocationSer.getLatitude();
      var longitude = geoLocationSer.getLongitude();

      /*重定位 */
      function reLocated() {
        geoLocationSer.reLocated();
        latitude = geoLocationSer.getLatitude();
        longitude = geoLocationSer.getLongitude();
      }
      reLocated();

      /**刷新**/
      function refresh() {
        merchantSer.refresh(longitude, latitude, $scope.search.name, 1, size).then(function (data) {
          if (data.errcode == undefined) {
            if (data.length == 0) {
              $ionicLoading.show({
                template: '附近没有服务',
                duration: 1000
              });
            } else if (data.length < size) {
              $scope.hasMore = false;
            } else {
              $scope.hasMore = true;
            }
            page = 2;
            $scope.merchants = data;
          } else {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function (error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        })
          .finally(function () {
            $scope.$broadcast('scroll.refreshComplete');
          });
      }
      refresh();

      /**手动刷新**/
      $scope.doRefresh = function () {
        $scope.search.name = '';
        reLocated();
        refresh();
      };

      /**更多**/
      $scope.more = function () {
        merchantSer.more(longitude, latitude, $scope.search.name, page, size).then(function (data) {
          if (data.errcode == undefined) {
            if (data.length == 0) {
              $ionicLoading.show({
                template: '没有更多服务。',
                duration: 1000
              });
              $scope.hasMore = false;
            } else if (data.length < size) {
              $scope.hasMore = false;
            }
            page++;
            $scope.merchants = $scope.merchants.concat(data);
          } else {
            $scope.hasMore = false;
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function (error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        })
          .finally(function () {
            $scope.$broadcast('scroll.infiniteScrollComplete');
          });
      };

      /*=================服务单位点赞开始================*/
      $scope.changeLikes = function (index, event) {
        event.preventDefault();
        $scope.merchant_likes = $scope.merchants[index];
        if ($scope.merchant_likes.has_likes === true) { //取消点赞
          //$scope.show_likes = false;
        } else if ($scope.merchant_likes.has_likes === undefined || $scope.merchant_likes.has_likes === false) { //点赞
          var token = localStorage.getItem('bj12351.token');
          if (token) {
            merchantSer.postMerchantLikes(token, $scope.merchant_likes.id).then(function (data) {
              if (data.errcode === 0 || data.errcode === undefined) {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的').then(function () {
                  var heart = !$scope.merchant_likes.has_likes;
                  $scope.merchant_likes.has_likes = heart;
                  $scope.merchants[index].likes_count = $scope.merchant_likes.likes_count + 1;
                  $scope.merchants[index].has_likes = true;
                });
              } else if (data.errcode == -1) {
                $cordovaDialogs.alert('请先登录', '温馨提示', '好的').then(function () {
                  // $location.path('/login');
                  $scope.is_gesture = localStorage.getItem('bj12351.is_gesture_pwd');
                  if ($scope.is_gesture === "true") {
                    $state.go('tab.login');
                  } else {
                    $state.go('tab.login-other');
                  }
                });
              } else {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
              }
            },
              function (error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
          } else {
            $cordovaDialogs.alert('请先登录', '温馨提示', '好的').then(function () {
              // $location.path('/login');
              $scope.is_gesture = localStorage.getItem('bj12351.is_gesture_pwd');
              if ($scope.is_gesture === "true") {
                $state.go('tab.login');
              } else {
                $state.go('tab.login-other');
              }
            });
          }

        }
      };
      /*=================服务单位点赞结束================*/

      /**模板方法**/
      $scope.modal = {};
      $scope.openModal = function (modal_name) {
        if (!!$scope.modal[modal_name] && $scope.modal[modal_name]._isShown) {
          return;
        }
        $ionicModal.fromTemplateUrl(templateUrlPath + 'modules/modals/' + modal_name + '.html', {
          scope: $scope,
          animation: 'slide-in-right'
        }).then(function (modal) {
          $scope.modal[modal_name] = modal;
          $scope.modal[modal_name].show();
        });
      };

      $scope.closeModal = function (modal_name) {
        $scope.modal[modal_name].remove();
      };

      $scope.submitModal = function (modal_name) {
        refresh();
        $scope.modal[modal_name].remove();
      };

    });
})();
