(function() {
  'use strict';
  angular
    .module('merchantDetail')
    .controller('merchantDetailCtrl', function($scope, $state, $cordovaDialogs, $stateParams, $ionicModal, $ionicLoading, $ionicHistory, templateUrlPath, merchantDetailSer, geoLocationSer, $cordovaLaunchNavigator, $cordovaInAppBrowser, $cordovaDevice) {
      var page = 1;
      var size = 10;

      $scope.merchant = {}; //服务单位
      $scope.comment = {}; //评价
      $scope.comments = []; //评价列表
      $scope.commentHasMore = false;

      /**刷新**/
      $scope.refresh = function() {
        geoLocationSer.reLocated();
        merchantDetailSer.detail($stateParams.merchantId).then(function(data) {
            if (data.errcode === undefined) {
              $scope.merchant = data;
              $scope.refreshComments();
              //加载地理编码插件
              AMap.plugin(["AMap.Geocoder"], function() {
                var myGeo = new AMap.Geocoder({
                  city: "北京"
                });
                myGeo.getLocation($scope.merchant.address, function(status, result) {
                  console.log("status",status);
                  console.log("result",result);
                  if (status === 'complete' && result.info === 'OK') {
                    console.log(result.geocodes[0].location);
                    $scope.desLat = result.geocodes[0].location.lat;
                    $scope.desLng = result.geocodes[0].location.lng;
                  }
                });
              });
            } else {
              $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的').then(function() {
                $ionicHistory.goBack();
              });
            }
          }, function(error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          })
          .finally(function() {
            $scope.$broadcast('scroll.refreshComplete');
          });
      };
      $scope.refresh();

      $scope.launchNavigatorForIos = function() {
        $cordovaLaunchNavigator.navigate($scope.merchant.address).then(function() {
          // console.log("Navigator launched");
        }, function(err) {
          console.error(err);
        });
      };
      $scope.launchNavigator = function() {
        if ($cordovaDevice.getPlatform() === 'iOS') {
          $scope.launchNavigatorForIos();
        } else if ($cordovaDevice.getPlatform() === 'Android') {
          appAvailability.check('com.baidu.BaiduMap',
            function() { // Success start Bmap
              var targetSrc = 'http://api.map.baidu.com/direction?origin=latlng:' + geoLocationSer.getLatitude() + ',' + geoLocationSer.getLongitude() + '|name:您所在位置&destination=' + $scope.merchant.address + '&mode=driving&region=北京&output=html&src=测试北京12351app';
              $cordovaInAppBrowser.open(targetSrc, '_system', {
                clearcache: 'yes',
                clearsessioncache: 'yes',
                keyboardDisplayRequiresUserAction: 'no'
              });
            },
            function() { // Fail start Amap
              var targetSrc = 'http://uri.amap.com/navigation?from=&to=' + $scope.desLng + ',' + $scope.desLat + ',' + $scope.merchant.address + '&mode=car&policy=1&src=mypage&coordinate=gaode&callnative=1';
              $cordovaInAppBrowser.open(targetSrc, '_system', {
                clearcache: 'yes',
                clearsessioncache: 'yes',
                keyboardDisplayRequiresUserAction: 'no'
              });
            });
        }
      };

      /**刷新评价**/
      $scope.refreshComments = function() {
        if ($scope.merchant.comment_count == 0) {
          //return;
        }
        merchantDetailSer.getComments($stateParams.merchantId, 1, size).then(function(data) {
            if (data.errcode === undefined) {
              if (data.length < size) {
                $scope.commentHasMore = false;
              } else {
                $scope.commentHasMore = true;
              }
              page = 2;
              $scope.comments = data;
            }
          }, function(error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          })
          .finally(function() {
            $scope.$broadcast('scroll.refreshComplete');
          });
      };

      /**更多评价**/
      $scope.moreComments = function() {
        merchantDetailSer.getComments($stateParams.merchantId, page, size).then(function(data) {
            if (data.errcode === undefined) {
              if (data.length == 0) {
                $ionicLoading.show({
                  template: '没有更多评价。',
                  duration: 1000
                });
                $scope.commentHasMore = false;
              } else if (data.length < size) {
                $scope.commentHasMore = false;
              }
              page++;
              $scope.comments = $scope.comments.concat(data);
            }
          }, function(error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          })
          .finally(function() {
            $scope.$broadcast('scroll.infiniteScrollComplete');
          });
      };

      /**显示图片**/
      $scope.showImg = function(url) {
        $scope.openModal('show_img');
      };

      /**添加评价**/
      $scope.addComment = function() {
        if (!!localStorage.getItem('bj12351.token')) {
          merchantDetailSer.isTaked($stateParams.merchantId).then(function(data) {
            if (data.errcode == 0) {
              if (data.is_taked) {
                $scope.merchant.img = $scope.merchant.pics[0].src;
                $scope.comment.star = 5;
                $scope.comment.content = '';
                $scope.comment.is_anonymity = true;
                $scope.openModal('comment/add_comment');
              } else {
                $cordovaDialogs.alert('您还没有参加过此服务单位的活动，暂时无法评价，快去参与吧~', '温馨提示', '好的');
              }
            } else if (data.errcode == -1) {
              $cordovaDialogs.confirm('您尚未登录哦', '温馨提示', ['现在登录', '稍后登录']).then(function(buttonIndex) {
                if (buttonIndex == 1) {
                  $scope.closeModal('comment/comments');
                  $scope.is_gesture = localStorage.getItem('bj12351.is_gesture_pwd');
                  if ($scope.is_gesture === "true") {
                    $state.go('tab.login');
                  } else {
                    $state.go('tab.login-other');
                  }
                }
              });
            } else {
              $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
            }
          }, function(error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          });
        } else {
          $cordovaDialogs.confirm('您尚未登录哦', '温馨提示', ['现在登录', '稍后登录']).then(function(buttonIndex) {
            if (buttonIndex == 1) {
              $scope.closeModal('comment/comments');
              $scope.is_gesture = localStorage.getItem('bj12351.is_gesture_pwd');
              if ($scope.is_gesture === "true") {
                $state.go('tab.login');
              } else {
                $state.go('tab.login-other');
              }
            }
          });
        }
      };

      /**提交评价**/
      $scope.submitComment = function(modal_name) {
        var star = $scope.comment.star;
        var content = $scope.comment.content;
        var is_anonymity = $scope.comment.is_anonymity;
        merchantDetailSer.submitComment($stateParams.merchantId, content, star, is_anonymity).then(function(data) {
          if (data.errcode == 0) {
            var now = new Date();
            $scope.comments.unshift({
              content: content,
              star: star,
              is_anonymity: is_anonymity,
              member_name: JSON.parse(localStorage.getItem('bj12351.user')).name,
              create_at: now.getFullYear() + '-' + (now.getMonth() + 1) + '-' + now.getDate() + ' ' + now.getHours() + ':' + now.getMinutes() + ':' + now.getSeconds()
            });
            $scope.closeModal(modal_name);
            $cordovaDialogs.alert('评价成功。', '温馨提示', '好的');
            $scope.refresh();
          } else {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function(error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        });
      };

      /**模板方法**/
      $scope.modal = {};
      $scope.openModal = function(modal_name) {
        if (!!$scope.modal[modal_name] && $scope.modal[modal_name]._isShown) {
          return;
        }
        var option = {
          scope: $scope,
          animation: 'slide-in-right'
        };
        if (modal_name == 'show_img' || modal_name == 'comment/add_comment') {
          option.animation = 'slide-in-up';
        }
        $ionicModal.fromTemplateUrl(templateUrlPath + 'modules/modals/' + modal_name + '.html', option).then(function(modal) {
          $scope.modal[modal_name] = modal;
          $scope.modal[modal_name].show();
        });
      };

      $scope.closeModal = function(modal_name) {
        $scope.modal[modal_name].remove();
      };

      /**强制显示返回按钮**/
      $scope.$on('$ionicView.beforeEnter', function(event, viewData) {
        viewData.enableBack = true;
      });

    });
})();
