(function() {
  'use strict';

  angular
    .module('credits')
    .controller('creditsCtrl', creditsCtrl);

  creditsCtrl.$inject = ['$scope', '$ionicSlideBoxDelegate', '$ionicLoading', '$state', '$interval', '$stateParams', '$location', '$cordovaDialogs', '$ionicModal', 'templateUrlPath', 'creditsSer'];

  function creditsCtrl($scope, $ionicSlideBoxDelegate, $ionicLoading, $state, $interval, $stateParams, $location, $cordovaDialogs, $ionicModal, templateUrlPath, creditsSer) {
    $scope.logistics = {};
    $scope.logistics.award_apply_id = '';
    $scope.logistics.award_id = '';
    $scope.logistics.name = '';
    $scope.logistics.mobile = '';
    $scope.logistics.address = '';
    $scope.logistics.postcode = '';
    $scope.integral_num = '';
    $scope.sort = 'points';
    $scope.dir = "desc";
    $scope.creditsCount = function() {
      creditsSer.creditsCount().then(function(data) {
        if (data.errcode === 0) {
          $scope.integral_num = data.integral_num;
        }
      });
    };

    $scope.modal = {};
    $scope.openModal = function(modal_name) {
      $ionicModal.fromTemplateUrl(templateUrlPath + 'modules/modals/' + modal_name + '.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function(modal) {
        $scope.modal[modal_name] = modal;
        $scope.modal[modal_name].show();
      });
    };
    $scope.closeModal = function(modal_name) {
      $scope.logistics.award_apply_id = '';
      $scope.logistics.award_id = '';
      $scope.logistics.name = '';
      $scope.logistics.mobile = '';
      $scope.logistics.address = '';
      $scope.logistics.postcode = '';
      $scope.modal[modal_name].remove();
    };
    $scope.toState = function(route) {
      $state.go(route);
    };

    $scope.awardList = creditsSer.getAwardList();
    var page = 1;
    var size = 10;
    $scope.hasMore = $scope.awardList.length >= size;
    $scope.refresh = function() {
      $scope.creditsCount();
      creditsSer.refreshAwardList(1, size).then(function(data) {
          if (data.errcode == undefined) {
            if (data.length == 0) {
              $ionicLoading.show({
                template: '暂时没有奖品。',
                duration: 1000
              });
            } else if (data.length < size) {
              $scope.hasMore = false;
            } else {
              $scope.hasMore = true;
            }
            page = 2;
            $scope.awardList = data;
          } else {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function(error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        })
        .finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
    };
    $scope.refresh();

    $scope.more = function() {
      creditsSer.moreAwardList(page, size).then(function(data) {
          if (data.errcode == undefined) {
            if (data.length == 0) {
              $ionicLoading.show({
                template: '没有更多奖品。',
                duration: 1000
              });
              $scope.hasMore = false;
            } else if (data.length < size) {
              $scope.hasMore = false;
            }
            page++;
            $scope.awardList = $scope.awardList.concat(data);
          } else {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function(error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        })
        .finally(function() {
          $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    };
    //查看大图
    $scope.viewPic = function(modal_name, url) {
      $scope.largePic = url;
      $scope.openModal(modal_name);
    };
    /**隐藏兑换详情**/
    $scope.hideExchangeDetail = function(index) {
      $scope.awardList[index].hideDetail = !$scope.awardList[index].hideDetail;
    };
    /**隐藏兑换详情**/
    $scope.hideExchangeDetail2 = function(index) {
      $scope.exchangeHistorylist[index].hideDetail = !$scope.exchangeHistorylist[index].hideDetail;
    };

    $scope.applyAward = function(award_id, award_type, send_type) {
      creditsSer.applyAward(award_id).then(function(data) {
        $scope.creditsCode = JSON.stringify(data);
        if (data.errcode === 0) {
          if (award_type == 2 && send_type == 2) {
            $scope.openModal('credits_show_qrcode');
          } else if (award_type == 2 && send_type == 1) {
            $scope.logistics.award_apply_id = data.award_apply_id;
            $scope.logistics.award_id = award_id;
            $scope.openModal('credits_logistics');
          }
        } else {
          $cordovaDialogs.alert(data.errmsg, '温馨提示', '确定');
        }
      }, function(error) {
        $ionicLoading.show({
          template: '网络繁忙，请稍后重试。',
          duration: 1000
        });
      });
    };

    $scope.convertAward = function(award_apply_id, award_id, award_type, send_type) {
      if (award_type == 2 && send_type == 1) {
        award_apply_id = $scope.logistics.award_apply_id;
        award_id = $scope.logistics.award_id;
        if ($scope.logistics.name == '') {
          $cordovaDialogs.alert('姓名不能为空！', '温馨提示', '好的');
          return;
        }
        if ($scope.logistics.mobile.toString().length === 0) {
          $cordovaDialogs.alert('手机号不能为空！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }

        if ($scope.logistics.mobile.toString().length != 11) {
          $cordovaDialogs.alert('请正确填写手机号！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }
        if ($scope.logistics.postcode != '' && $scope.logistics.postcode.toString().length != 6) {
          $cordovaDialogs.alert('请正确填写邮政编码！', '温馨提示', '好的');
          $scope.is_submit = false;
          return;
        }
        if ($scope.logistics.address == '') {
          $cordovaDialogs.alert('详细地址不能为空！', '温馨提示', '好的');
          return;
        }
      }
      creditsSer.convertAward(award_apply_id, award_id, award_type, send_type, $scope.logistics.name, $scope.logistics.mobile, $scope.logistics.address, $scope.logistics.postcode)
        .then(function(data) {
          if (data.errcode === 0) {
            if (award_type == 1) {
              $cordovaDialogs.alert(data.errmsg + '，您可在兑换历史中查看电子码。', '温馨提示', '确定');
            } else {
              $cordovaDialogs.alert(data.errmsg + '，您可在兑换历史中查看物流单号。', '温馨提示', '确定');
              $scope.closeModal('credits_logistics');
            }
          } else {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '确定');
          }
        }, function(error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        });
    };

    $scope.convert = function(award_id, award_type, send_type) {
      $cordovaDialogs.confirm('您确定要兑换该物品吗？', '温馨提示', ['确定', '取消']).then(function(buttonIndex) {
        if (buttonIndex == 1 && award_type == 2) { //实物类
          $scope.applyAward(award_id, award_type, send_type);
        } else if (buttonIndex == 1 && award_type == 1) { //电子码
          $scope.convertAward(0, award_id, award_type, send_type);
        }
      });
    };

  }
})();
