(function () {
  'use strict';

  angular
    .module('station')
    .controller('stationCtrl', function ($scope, $ionicModal, $ionicLoading, $cordovaDialogs, stationSer, geoLocationSer, merchantSer, templateUrlPath) {
      $scope.search = {};
      $scope.search.name = '';

      var page = 1;
      var size = 10;
      $scope.stations = stationSer.getStations();
      $scope.hasMore = $scope.stations.length >= size;

      var latitude = geoLocationSer.getLatitude();
      var longitude = geoLocationSer.getLongitude();

      $scope.district_options = [{
        code: 0,
        name: '全部区域'
      }, {
        code: 1398,
        name: '东城区'
      }, {
        code: 1428,
        name: '西城区'
      }, {
        code: 1523,
        name: '海淀区'
      }, {
        code: 1539,
        name: '朝阳区'
      }, {
        code: 1610,
        name: '丰台区'
      }, {
        code: 1654,
        name: '门头沟区'
      }, {
        code: 1633,
        name: '石景山区'
      }, {
        code: 1647,
        name: '房山区'
      }, {
        code: 1682,
        name: '昌平区'
      }, {
        code: 1661,
        name: '通州区'
      }, {
        code: 948,
        name: '平谷区'
      }, {
        code: 966,
        name: '怀柔区'
      }, {
        code: 978,
        name: '顺义区'
      }, {
        code: 1063,
        name: '大兴区'
      }, {
        code: 1053,
        name: '延庆区'
      }, {
        code: 1088,
        name: '密云区'
      }, {
        code: 1100,
        name: '经济技术开发区'
      }];
      $scope.search.district = $scope.district_options[0];

      /*重定位 */
      function reLocated(){
        geoLocationSer.reLocated();
        latitude = geoLocationSer.getLatitude();
        longitude = geoLocationSer.getLongitude();        
      }
      reLocated();

      /**刷新**/
      $scope.refresh = function () {
        stationSer.refresh(longitude, latitude, $scope.search.name, 1, size, $scope.search.district.code)
          .then(function (data) {
            if (data.errcode == undefined) {
              if (data.length == 0) {
                $ionicLoading.show({
                  template: '暂无工会服务站，敬请期待。',
                  duration: 1000
                });
                $scope.hasMore = false;
              } else if (data.length < size) {
                $scope.hasMore = false;
              } else {
                $scope.hasMore = true;
              }
              page = 2;
              $scope.stations = data;
            } else {
              $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
            }
          }, function (error) {
            $ionicLoading.show({
              template: '网络繁忙，请稍后重试。',
              duration: 1000
            });
          })
          .finally(function () {
            $scope.$broadcast('scroll.refreshComplete');
          });
      };
      $scope.refresh();

      /**手动刷新**/
      $scope.doRefresh = function () {
        $scope.search.name = '';
        reLocated();
        $scope.refresh();
      };

      /**更多**/
      $scope.more = function () {
        stationSer.more(longitude, latitude, $scope.search.name, page, size, $scope.search.district.code).then(function (data) {
          if (data.errcode == undefined) {
            if (data.length == 0) {
              $ionicLoading.show({
                template: '无更多工会服务站。',
                duration: 1000
              });
              $scope.hasMore = false;
            } else if (data.length < size) {
              $scope.hasMore = false;
            }
            page++;
            $scope.stations = $scope.stations.concat(data);
          } else {
            $scope.hasMore = false;
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          }
        }, function (error) {
          $ionicLoading.show({
            template: '网络繁忙，请稍后重试。',
            duration: 1000
          });
        })
          .finally(function () {
            $scope.$broadcast('scroll.infiniteScrollComplete');
          });
      };

      /*=================工会服务站点赞开始================*/
      $scope.changeLikes = function (index, event) {
        event.preventDefault();
        $scope.station_likes = $scope.stations[index];
        if ($scope.station_likes.has_likes === true) { //取消点赞
          //$scope.show_likes = false;
        } else if ($scope.station_likes.has_likes === undefined || $scope.station_likes.has_likes === false) { //点赞
          var token = localStorage.getItem('bj12351.token');
          if (token) {
            merchantSer.postMerchantLikes(token, $scope.station_likes.id).then(function (data) {
              if (data.errcode === 0 || data.errcode === undefined) {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的').then(function () {
                  var heart = !$scope.station_likes.has_likes;
                  $scope.station_likes.has_likes = heart;
                  $scope.stations[index].likes_count = $scope.station_likes.likes_count + 1;
                  $scope.stations[index].has_likes = true;
                });
              } else {
                $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
              }
            },
              function (error) {
                $ionicLoading.show({
                  template: '网络繁忙，请稍后重试。',
                  duration: 1000
                });
              });
          } else {
            $cordovaDialogs.alert('请先登录', '温馨提示', '好的').then(function () {
              // $location.path('/login');
              $scope.is_gesture = localStorage.getItem('bj12351.is_gesture_pwd');
              if ($scope.is_gesture === "true") {
                $state.go('tab.login');
              } else {
                $state.go('tab.login-other');
              }
            });
          }

        }
      };
      /*=================工会服务站点赞结束================*/


      /***模板方法*/
      $scope.modal = {};
      $scope.openModal = function (modal_name) {
        if (!!$scope.modal[modal_name] && $scope.modal[modal_name]._isShown) {
          return;
        }
        $ionicModal.fromTemplateUrl(templateUrlPath + 'modules/modals/' + modal_name + '.html', {
          scope: $scope,
          animation: 'slide-in-right'
        }).then(function (modal) {
          $scope.modal[modal_name] = modal;
          $scope.modal[modal_name].show();
        });
      };

      $scope.closeModal = function (modal_name) {
        $scope.modal[modal_name].remove();
      };

      $scope.submitModal = function (modal_name) {
        $scope.refresh();
        $scope.modal[modal_name].remove();
      };

    });
})();
